@@ -30,7 +30,6 @@ netsnmp_feature_child_of(ipaddress_arch_entry_copy, ipaddress_common);
 netsnmp_feature_require(ipaddress_ioctl_entry_copy);
 #endif /* NETSNMP_FEATURE_REQUIRE_IPADDRESS_ARCH_ENTRY_COPY */
 
-#if defined (NETSNMP_ENABLE_IPV6)
 #include <linux/types.h>
 #include <asm/types.h>
 #if defined(HAVE_LINUX_RTNETLINK_H)
@@ -40,7 +39,6 @@ netsnmp_feature_require(ipaddress_ioctl_entry_copy);
 #define SUPPORT_PREFIX_FLAGS 1
 #endif /* RTMGRP_IPV6_PREFIX */
 #endif /* HAVE_LINUX_RTNETLINK_H */
-#endif
 
 #include "ipaddress.h"
 #include "ipaddress_ioctl.h"
@@ -220,7 +218,7 @@ _load_v6(netsnmp_container *container, int idx_offset)
                 "cannot get ip address information"
                 "as netlink socket is not available\n"));
     return -1;
-#else
+#else /* HAVE_LINUX_RTNETLINK_H */
     FILE           *in;
     char            line[80], addr[40];
     char            if_name[IFNAMSIZ+1];/* +1 for '\0' because of the ugly sscanf below */ 
@@ -430,7 +428,9 @@ _load_v6(netsnmp_container *container, int idx_offset)
         return rc;
 
     return idx_offset;
+#endif /* HAVE_LINUX_RTNETLINK_H */
 }
+#endif /* NETSNMP_ENABLE_IPV6 */
 
 struct address_flag_info
 netsnmp_access_other_info_get(int index, int family)
@@ -519,9 +519,9 @@ netsnmp_access_other_info_get(int index, int family)
 out:
     close(sd);
     return addr;
-#endif
 }
 
+#if defined (NETSNMP_ENABLE_IPV6)
 #ifdef HAVE_LINUX_RTNETLINK_H
 int
 netsnmp_access_ipaddress_extra_prefix_info(int index, u_long *preferedlt,
@@ -621,6 +621,5 @@ out:
     close(sd);
     return ret;
 }
-#endif
-#endif
-
+#endif /* HAVE_LINUX_RTNETLINK_H */
+#endif /* defined(NETSNMP_ENABLE_IPV6) */
